@@ -11,7 +11,7 @@ ex::lib - The same as C<lib>, but makes relative path absolute.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -66,7 +66,7 @@ Mons Anderson, C<< <mons@cpan.org> >>
 
 use strict;
 use lib ();
-our $VERSION = 0.02;
+$ex::lib::VERSION = 0.03;
 
 BEGIN {
 	# use constants is heavy :(
@@ -90,33 +90,55 @@ sub mkapath($) {
 	
 	# Prepare absolute base bath
 	my ($pkg,$file) = (caller($depth))[0,1];
-	warn "file = $file " if DEBUG;
+	warn "file = $file " if DEBUG > 1;
+	$file =~ s{[^/]+$}{}s;
+	$file = '.' unless length $file;
+	warn "base path = $file" if DEBUG > 1;
 	#( my $p = $pkg  ) =~ s{::}{/}g;
 	#( my $f = $file ) =~ s/\Q$p.pm\E$//i;
-	( my $f = abs_path($file) ) =~ s{[^/]+$}{}i;
-	warn "source dir = $f " if DEBUG;
+	my $f = abs_path($file) . '/';
+	warn "source dir = $f " if DEBUG > 1;
 	$f;
 }
 
+sub transform {
+	local $@; # Don't poison $@
+	my $prefix;
+	map {
+		ref || m{^/} ? $_ : do {
+			my $lib = $_;
+			s{^\./+}{};
+			local $!;
+			my $abs = ( $prefix ||= mkapath(2) ) . $_;
+			$_ = abs_path( $abs ) or _croak("Bad path specification: `$lib' => `$abs'" . ($! ? " ($!)" : ''));
+			warn "$lib => $_" if DEBUG > 1;
+			$_;
+		}
+	} @_;
+}
+
 sub import {
 	shift;
 	local $@; # Don't poison $@
 	
 	_croak("Bad usage. use ".__PACKAGE__." PATH") unless @_;
-	my $prefix = mkapath(1);
-	@_ = @_;
-	for (@_) {
-		ref and next;
-		my $lib = $_;
-		s{^\./}{};
-		$_ = abs_path("$prefix$_") or _croak("Bad path specification");
-	}
-	warn "use explicit lib: '@_'\n" if DEBUG;
-	unshift @_, 'lib';
+
+	@_ = ( lib => transform @_ = @_ );
+	warn "use @_\n" if DEBUG > 0;
 	goto &lib::import;
 	return;
 }
 
+sub unimport {
+	shift;
+	local $@; # Don't poison $@
+	_croak("Bad usage. use ".__PACKAGE__." PATH") unless @_;
+	@_ = ( lib => transform @_ = @_ );
+	warn "no @_\n" if DEBUG > 0;
+	goto &lib::unimport;
+	return;
+}
+
 
 # From Cwd;
 
